"""A python package to help facilitate the collection and analysis of education-related datasets. """

# change to calendar versioning of sorts, last digit is a version within the mmddv
__version__ = '2022.03242'


from pypeds.ipeds import *
from pypeds.datasets import *
from pypeds.views import *



